summaryrefslogtreecommitdiff
path: root/src/gui
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui')
-rw-r--r--src/gui/browserbox.cpp8
-rw-r--r--src/gui/chat.cpp14
-rw-r--r--src/gui/color.cpp (renamed from src/gui/colour.cpp)50
-rw-r--r--src/gui/color.h (renamed from src/gui/colour.h)62
-rw-r--r--src/gui/equipmentwindow.h12
-rw-r--r--src/gui/gui.cpp2
-rw-r--r--src/gui/itemcontainer.cpp11
-rw-r--r--src/gui/itemcontainer.h6
-rw-r--r--src/gui/itempopup.cpp4
-rw-r--r--src/gui/itempopup.h6
-rw-r--r--src/gui/itemshortcutcontainer.cpp1
-rw-r--r--src/gui/listbox.cpp8
-rw-r--r--src/gui/login.cpp10
-rw-r--r--src/gui/ministatus.cpp36
-rw-r--r--src/gui/ministatus.h14
-rw-r--r--src/gui/popupmenu.cpp99
-rw-r--r--src/gui/popupmenu.h4
-rw-r--r--src/gui/recorder.cpp2
-rw-r--r--src/gui/recorder.h2
-rw-r--r--src/gui/setup.cpp4
-rw-r--r--src/gui/setup_colors.cpp (renamed from src/gui/setup_colours.cpp)73
-rw-r--r--src/gui/setup_colors.h (renamed from src/gui/setup_colours.h)10
-rw-r--r--src/gui/setup_keyboard.cpp5
-rw-r--r--src/gui/setup_keyboard.h4
-rw-r--r--src/gui/setup_players.cpp24
-rw-r--r--src/gui/setup_video.cpp4
-rw-r--r--src/gui/shoplistbox.cpp8
-rw-r--r--src/gui/skill.cpp32
-rw-r--r--src/gui/skill.h2
-rw-r--r--src/gui/speechbubble.cpp13
-rw-r--r--src/gui/speechbubble.h13
-rw-r--r--src/gui/status.cpp4
-rw-r--r--src/gui/table.cpp65
-rw-r--r--src/gui/table.h37
-rw-r--r--src/gui/table_model.cpp16
-rw-r--r--src/gui/table_model.h35
-rw-r--r--src/gui/truetypefont.cpp7
-rw-r--r--src/gui/truetypefont.h6
-rw-r--r--src/gui/viewport.cpp6
-rw-r--r--src/gui/widgets/dropdown.cpp6
-rw-r--r--src/gui/window.cpp1
-rw-r--r--src/gui/window.h6
42 files changed, 403 insertions, 329 deletions
diff --git a/src/gui/browserbox.cpp b/src/gui/browserbox.cpp
index 65659df6..48b1cda4 100644
--- a/src/gui/browserbox.cpp
+++ b/src/gui/browserbox.cpp
@@ -24,7 +24,7 @@
#include <guichan/graphics.hpp>
#include "browserbox.h"
-#include "colour.h"
+#include "color.h"
#include "linkhandler.h"
#include "truetypefont.h"
@@ -254,7 +254,7 @@ void BrowserBox::draw(gcn::Graphics *graphics)
bool valid;
if ((mHighMode & BACKGROUND))
{
- graphics->setColor(gcn::Color(textColour->getColour('H', valid)));
+ graphics->setColor(gcn::Color(textColor->getColor('H', valid)));
graphics->fillRectangle(gcn::Rectangle(
mLinks[mSelectedLink].x1,
mLinks[mSelectedLink].y1,
@@ -265,7 +265,7 @@ void BrowserBox::draw(gcn::Graphics *graphics)
if ((mHighMode & UNDERLINE))
{
- graphics->setColor(gcn::Color(textColour->getColour('<', valid)));
+ graphics->setColor(gcn::Color(textColor->getColor('<', valid)));
graphics->drawLine(
mLinks[mSelectedLink].x1,
mLinks[mSelectedLink].y2,
@@ -331,7 +331,7 @@ void BrowserBox::draw(gcn::Graphics *graphics)
else
{
bool valid;
- int rgb = textColour->getColour(c, valid);
+ int rgb = textColor->getColor(c, valid);
if (c == '<')
{
const int size = mLinks[link].x2 - mLinks[link].x1;
diff --git a/src/gui/chat.cpp b/src/gui/chat.cpp
index 92dd46d7..1c0cea13 100644
--- a/src/gui/chat.cpp
+++ b/src/gui/chat.cpp
@@ -143,13 +143,15 @@ void ChatWindow::chatLog(std::string line, int own, bool ignoreRecord)
case BY_GM:
if (tmp.nick.empty())
{
- tmp.nick = std::string(_("Global announcement: "));
+ tmp.nick = std::string(_("Global announcement:"));
+ tmp.nick += " ";
lineColor = "##G";
}
else
{
- tmp.nick = strprintf(_("Global announcement from %s: "),
+ tmp.nick = strprintf(_("Global announcement from %s:"),
tmp.nick.c_str());
+ tmp.nick += " ";
lineColor = "##1"; // Equiv. to BrowserBox::RED
}
break;
@@ -172,7 +174,8 @@ void ChatWindow::chatLog(std::string line, int own, bool ignoreRecord)
lineColor = "##P";
break;
case ACT_WHISPER:
- tmp.nick += CAT_WHISPER;
+ tmp.nick = strprintf(_("%s whispers:"), tmp.nick.c_str());
+ tmp.nick += " ";
lineColor = "##W";
break;
case ACT_IS:
@@ -234,7 +237,7 @@ void ChatWindow::chatLog(CHATSKILL act)
chatLog(const_msg(act), BY_SERVER);
}
-void ChatWindow::action(const gcn::ActionEvent & event)
+void ChatWindow::action(const gcn::ActionEvent &event)
{
if (event.getId() == "chatinput")
{
@@ -697,9 +700,8 @@ void ChatWindow::scroll(int amount)
mTextOutput->showPart(scr);
}
-void ChatWindow::keyPressed(gcn::KeyEvent & event)
+void ChatWindow::keyPressed(gcn::KeyEvent &event)
{
-
if (event.getKey().getValue() == Key::DOWN &&
mCurHist != mHistory.end())
{
diff --git a/src/gui/colour.cpp b/src/gui/color.cpp
index cdb5a3fd..e37affda 100644
--- a/src/gui/colour.cpp
+++ b/src/gui/color.cpp
@@ -19,40 +19,40 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
-#include "colour.h"
+#include "color.h"
#include "../configuration.h"
#include "../utils/gettext.h"
#include "../utils/tostring.h"
-Colour::Colour()
+Color::Color()
{
- addColour('C', 0x000000, _("Chat"));
- addColour('G', 0xff0000, _("GM"));
- addColour('H', 0xebc873, _("Highlight"));
- addColour('Y', 0x1fa052, _("Player"));
- addColour('W', 0x0000ff, _("Whisper"));
- addColour('I', 0xf1dc27, _("Is"));
- addColour('P', 0xff00d8, _("Party"));
- addColour('S', 0x8415e2, _("Server"));
- addColour('L', 0x919191, _("Logger"));
- addColour('<', 0xe50d0d, _("Hyperlink"));
+ addColor('C', 0x000000, _("Chat"));
+ addColor('G', 0xff0000, _("GM"));
+ addColor('H', 0xebc873, _("Highlight"));
+ addColor('Y', 0x1fa052, _("Player"));
+ addColor('W', 0x0000ff, _("Whisper"));
+ addColor('I', 0xf1dc27, _("Is"));
+ addColor('P', 0xff00d8, _("Party"));
+ addColor('S', 0x8415e2, _("Server"));
+ addColor('L', 0x919191, _("Logger"));
+ addColor('<', 0xe50d0d, _("Hyperlink"));
commit();
}
-Colour::~Colour()
+Color::~Color()
{
for (ColVector::iterator col = mColVector.begin(),
colEnd = mColVector.end();
col != colEnd;
++col)
{
- config.setValue("Colour" + col->text, toString(col->rgb));
+ config.setValue("color" + col->text, toString(col->rgb));
}
}
-void Colour::setColour(const char c, const int rgb)
+void Color::setColor(const char c, const int rgb)
{
for (ColVector::iterator col = mColVector.begin(),
colEnd = mColVector.end();
@@ -67,7 +67,7 @@ void Colour::setColour(const char c, const int rgb)
}
}
-int Colour::getColour(const char c, bool &valid) const
+int Color::getColor(const char c, bool &valid) const
{
for (ColVector::const_iterator col = mColVector.begin(),
colEnd = mColVector.end();
@@ -84,7 +84,7 @@ int Colour::getColour(const char c, bool &valid) const
return 0x000000;
}
-std::string Colour::getElementAt(int i)
+std::string Color::getElementAt(int i)
{
if (i < 0 || i >= getNumberOfElements())
{
@@ -93,7 +93,7 @@ std::string Colour::getElementAt(int i)
return mColVector[i].text;
}
-char Colour::getColourCharAt(int i)
+char Color::getColorCharAt(int i)
{
if (i < 0 || i >= getNumberOfElements())
{
@@ -102,13 +102,13 @@ char Colour::getColourCharAt(int i)
return mColVector[i].ch;
}
-void Colour::addColour(const char c, const int rgb, const std::string &text)
+void Color::addColor(const char c, const int rgb, const std::string &text)
{
- int trueRgb = config.getValue("Colour" + text, rgb);
- mColVector.push_back(ColourElem(c, trueRgb, text));
+ int trueRgb = config.getValue("color" + text, rgb);
+ mColVector.push_back(colorElem(c, trueRgb, text));
}
-int Colour::getColourAt(int i)
+int Color::getColorAt(int i)
{
if (i < 0 || i >= getNumberOfElements())
{
@@ -117,7 +117,7 @@ int Colour::getColourAt(int i)
return mColVector[i].rgb;
}
-void Colour::setColourAt(int i, int rgb)
+void Color::setColorAt(int i, int rgb)
{
if (i >= 0 && i < getNumberOfElements())
{
@@ -125,7 +125,7 @@ void Colour::setColourAt(int i, int rgb)
}
}
-void Colour::commit()
+void Color::commit()
{
for (ColVector::iterator i = mColVector.begin(), iEnd = mColVector.end();
i != iEnd;
@@ -135,7 +135,7 @@ void Colour::commit()
}
}
-void Colour::rollback()
+void Color::rollback()
{
for (ColVector::iterator i = mColVector.begin(), iEnd = mColVector.end();
i != iEnd;
diff --git a/src/gui/equipmentwindow.h b/src/gui/equipmentwindow.h
index 4ae3300f..c491062a 100644
--- a/src/gui/equipmentwindow.h
+++ b/src/gui/equipmentwindow.h
@@ -1,26 +1,26 @@
/*
* The Mana World
- * Copyright 2004 The Mana World Development Team
+ * Copyright (C) 2004 The Mana World Development Team
*
* This file is part of The Mana World.
*
- * The Mana World is free software; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* any later version.
*
- * The Mana World is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with The Mana World; if not, write to the Free Software
+ * along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
-#ifndef EQUIPMENT_WINDOW_H
-#define EQUIPMENT_WINDOW_H
+#ifndef EQUIPMENTWINDOW_H
+#define EQUIPMENTWINDOW_H
#include <guichan/actionlistener.hpp>
diff --git a/src/gui/gui.cpp b/src/gui/gui.cpp
index 7779a503..87304bd1 100644
--- a/src/gui/gui.cpp
+++ b/src/gui/gui.cpp
@@ -134,7 +134,7 @@ Gui::Gui(Graphics *graphics):
gcn::Widget::setGlobalFont(mGuiFont);
- // Load hits' colourful fonts
+ // Load hits' colorful fonts
try
{
hitRedFont = new gcn::ImageFont("graphics/gui/hits_red.png",
diff --git a/src/gui/itemcontainer.cpp b/src/gui/itemcontainer.cpp
index 5693d001..0beb5cfb 100644
--- a/src/gui/itemcontainer.cpp
+++ b/src/gui/itemcontainer.cpp
@@ -19,13 +19,14 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
-#include <SDL_mouse.h>
+#include "itemcontainer.h"
+
+#include "itempopup.h"
#include <guichan/mouseinput.hpp>
#include <guichan/selectionlistener.hpp>
-#include "itemcontainer.h"
-#include "itempopup.h"
+#include <SDL_mouse.h>
#include "../graphics.h"
#include "../inventory.h"
@@ -124,7 +125,7 @@ void ItemContainer::draw(gcn::Graphics *graphics)
// Draw item caption
graphics->setFont(getFont());
- graphics->setColor(0x000000);
+ graphics->setColor(gcn::Color(0, 0, 0));
graphics->drawText(
(item->isEquipped() ? "Eq." : toString(item->getQuantity())),
itemX + gridWidth / 2,
@@ -171,7 +172,6 @@ void ItemContainer::refindSelectedItem()
{
if (mSelectedItemIndex != NO_ITEM)
{
-
if (mInventory->getItem(mSelectedItemIndex) &&
mInventory->getItem(mSelectedItemIndex)->getId() == mLastSelectedItemId)
return; // we're already fine
@@ -204,6 +204,7 @@ void ItemContainer::setSelectedItemIndex(int index)
newSelectedItemIndex = NO_ITEM;
else
newSelectedItemIndex = index;
+
if (mSelectedItemIndex != newSelectedItemIndex)
{
mSelectedItemIndex = newSelectedItemIndex;
diff --git a/src/gui/itemcontainer.h b/src/gui/itemcontainer.h
index 23b9e5e1..71fcc5d0 100644
--- a/src/gui/itemcontainer.h
+++ b/src/gui/itemcontainer.h
@@ -118,17 +118,17 @@ class ItemContainer : public gcn::Widget,
/**
* Find the current item index by the most recently used item ID
*/
- void refindSelectedItem(void);
+ void refindSelectedItem();
/**
* Determine and set the height of the container.
*/
- void recalculateHeight(void);
+ void recalculateHeight();
/**
* Sends out selection events to the list of selection listeners.
*/
- void distributeValueChangedEvent(void);
+ void distributeValueChangedEvent();
/**
* Gets the slot index based on the cursor position.
diff --git a/src/gui/itempopup.cpp b/src/gui/itempopup.cpp
index ddce449a..df7afa48 100644
--- a/src/gui/itempopup.cpp
+++ b/src/gui/itempopup.cpp
@@ -205,9 +205,9 @@ unsigned int ItemPopup::getNumRows()
void ItemPopup::view(int x, int y)
{
if (windowContainer->getWidth() < (x + getWidth() + 5))
- x = windowContainer->getWidth() - getWidth();
+ x = windowContainer->getWidth() - getWidth();
if ((y - getHeight() - 10) < 0)
- y = 0;
+ y = 0;
else
y = y - getHeight() - 10;
setPosition(x, y);
diff --git a/src/gui/itempopup.h b/src/gui/itempopup.h
index 1d37346e..c820e3a0 100644
--- a/src/gui/itempopup.h
+++ b/src/gui/itempopup.h
@@ -5,18 +5,18 @@
*
* This file is part of The Mana World.
*
- * The Mana World is free software; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* any later version.
*
- * The Mana World is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with The Mana World; if not, write to the Free Software
+ * along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
diff --git a/src/gui/itemshortcutcontainer.cpp b/src/gui/itemshortcutcontainer.cpp
index d3cc2c22..42e3b853 100644
--- a/src/gui/itemshortcutcontainer.cpp
+++ b/src/gui/itemshortcutcontainer.cpp
@@ -81,6 +81,7 @@ void ItemShortcutContainer::draw(gcn::Graphics *graphics)
{
Graphics *g = static_cast<Graphics*>(graphics);
+ graphics->setColor(gcn::Color(0, 0, 0));
graphics->setFont(getFont());
for (int i = 0; i < mMaxItems; i++)
diff --git a/src/gui/listbox.cpp b/src/gui/listbox.cpp
index b63d6424..63e55e24 100644
--- a/src/gui/listbox.cpp
+++ b/src/gui/listbox.cpp
@@ -23,7 +23,7 @@
#include <guichan/graphics.hpp>
#include <guichan/listmodel.hpp>
-#include "colour.h"
+#include "color.h"
#include "listbox.h"
#include "../configuration.h"
@@ -44,9 +44,9 @@ void ListBox::draw(gcn::Graphics *graphics)
mAlpha = config.getValue("guialpha", 0.8);
bool valid;
- const int red = (textColour->getColour('H', valid) >> 16) & 0xFF;
- const int green = (textColour->getColour('H', valid) >> 8) & 0xFF;
- const int blue = textColour->getColour('H', valid) & 0xFF;
+ const int red = (textColor->getColor('H', valid) >> 16) & 0xFF;
+ const int green = (textColor->getColor('H', valid) >> 8) & 0xFF;
+ const int blue = textColor->getColor('H', valid) & 0xFF;
const int alpha = mAlpha * 255;
graphics->setColor(gcn::Color(red, green, blue, alpha));
diff --git a/src/gui/login.cpp b/src/gui/login.cpp
index 3c8e7cb3..47d5a99e 100644
--- a/src/gui/login.cpp
+++ b/src/gui/login.cpp
@@ -54,13 +54,9 @@ LoginDialog::LoginDialog(LoginData *loginData):
gcn::Label *portLabel = new gcn::Label(_("Port:"));
gcn::Label *dropdownLabel = new gcn::Label(_("Recent:"));
std::vector<std::string> dfltServer;
- dfltServer.push_back("www.aethyra.org");
- dfltServer.push_back("www.aethyra.org");
- dfltServer.push_back("209.168.213.109");
+ dfltServer.push_back("server.themanaworld.org");
std::vector<std::string> dfltPort;
- dfltPort.push_back("21001");
- dfltPort.push_back("22001");
- dfltPort.push_back("21001");
+ dfltPort.push_back("6901");
mServerList = new DropDownList("MostRecent00", dfltServer, dfltPort,
MAX_SERVER_LIST_SIZE);
mServerListBox = new ListBox(mServerList);
@@ -75,7 +71,7 @@ LoginDialog::LoginDialog(LoginData *loginData):
mServerListBox);
mServerDropDown->setOpaque(false);
- mKeepCheck = new CheckBox(_("Keep"), mLoginData->remember);
+ mKeepCheck = new CheckBox(_("Remember Username"), mLoginData->remember);
mOkButton = new Button(_("OK"), "ok", this);
mCancelButton = new Button(_("Cancel"), "cancel", this);
mRegisterButton = new Button(_("Register"), "register", this);
diff --git a/src/gui/ministatus.cpp b/src/gui/ministatus.cpp
index 13351915..7058d572 100644
--- a/src/gui/ministatus.cpp
+++ b/src/gui/ministatus.cpp
@@ -23,6 +23,7 @@
#include "ministatus.h"
#include "progressbar.h"
+#include "../animatedsprite.h"
#include "../configuration.h"
#include "../graphics.h"
#include "../localplayer.h"
@@ -55,6 +56,24 @@ MiniStatusWindow::MiniStatusWindow():
loadWindowState();
}
+void MiniStatusWindow::setIcon(int index, AnimatedSprite *sprite)
+{
+ if (index >= (int) mIcons.size())
+ mIcons.resize(index + 1, NULL);
+
+ if (mIcons[index])
+ delete mIcons[index];
+
+ mIcons[index] = sprite;
+}
+
+void MiniStatusWindow::eraseIcon(int index)
+{
+ mIcons.erase(mIcons.begin() + index);
+}
+
+extern volatile int tick_time;
+
void MiniStatusWindow::update()
{
// HP Bar coloration
@@ -102,6 +121,11 @@ void MiniStatusWindow::update()
*/
mXpBar->setText(updatedText.str());
+
+ for (unsigned int i = 0; i < mIcons.size(); i++)
+ if (mIcons[i])
+ mIcons[i]->update(tick_time * 10);
+
}
void MiniStatusWindow::draw(gcn::Graphics *graphics)
@@ -109,3 +133,15 @@ void MiniStatusWindow::draw(gcn::Graphics *graphics)
update();
drawChildren(graphics);
}
+
+void MiniStatusWindow::drawIcons(Graphics *graphics)
+{
+ // Draw icons
+ int icon_x = mXpBar->getX() + mXpBar->getWidth() + 4;
+ for (unsigned int i = 0; i < mIcons.size(); i++) {
+ if (mIcons[i]) {
+ mIcons[i]->draw(graphics, icon_x, 3);
+ icon_x += 2 + mIcons[i]->getWidth();
+ }
+ }
+}
diff --git a/src/gui/ministatus.h b/src/gui/ministatus.h
index 832475f1..f262a2a0 100644
--- a/src/gui/ministatus.h
+++ b/src/gui/ministatus.h
@@ -24,6 +24,9 @@
#include "window.h"
+#include <vector>
+
+class AnimatedSprite;
class ProgressBar;
/**
@@ -44,6 +47,15 @@ class MiniStatusWindow : public Window
*/
void draw(gcn::Graphics *graphics);
+ /**
+ * Sets one of the icons.
+ */
+ void setIcon(int index, AnimatedSprite *sprite);
+
+ void eraseIcon(int index);
+
+ void drawIcons(Graphics *graphics);
+
private:
/**
* Updates this dialog with values from player_node.
@@ -56,6 +68,8 @@ class MiniStatusWindow : public Window
ProgressBar *mHpBar;
ProgressBar *mMpBar;
ProgressBar *mXpBar;
+
+ std::vector<AnimatedSprite *> mIcons;
};
#endif
diff --git a/src/gui/popupmenu.cpp b/src/gui/popupmenu.cpp
index 53c24960..be5252f7 100644
--- a/src/gui/popupmenu.cpp
+++ b/src/gui/popupmenu.cpp
@@ -29,6 +29,7 @@
#include "windowcontainer.h"
#include "../being.h"
+#include "../beingmanager.h"
#include "../floor_item.h"
#include "../item.h"
#include "../localplayer.h"
@@ -47,7 +48,7 @@ extern std::string tradePartnerName;
PopupMenu::PopupMenu():
Window(),
- mBeing(NULL),
+ mBeingId(0),
mFloorItem(NULL),
mItem(NULL)
{
@@ -65,38 +66,38 @@ PopupMenu::PopupMenu():
void PopupMenu::showPopup(int x, int y, Being *being)
{
- mBeing = being;
+ mBeingId = being->getId();
mBrowserBox->clearRows();
- switch (mBeing->getType())
+ switch (being->getType())
{
case Being::PLAYER:
{
// Players can be traded with. Later also attack, follow and
// add as buddy will be options in this menu.
- const std::string &name = mBeing->getName();
+ const std::string &name = being->getName();
mBrowserBox->addRow(strprintf(_("@@trade|Trade With %s@@"), name.c_str()));
mBrowserBox->addRow(strprintf(_("@@attack|Attack %s@@"), name.c_str()));
mBrowserBox->addRow("##3---");
switch (player_relations.getRelation(name)) {
- case PlayerRelation::NEUTRAL:
- mBrowserBox->addRow(strprintf(_("@@friend|Befriend %s@@"), name.c_str()));
-
- case PlayerRelation::FRIEND:
- mBrowserBox->addRow(strprintf(_("@@disregard|Disregard %s@@"), name.c_str()));
- mBrowserBox->addRow(strprintf(_("@@ignore|Ignore %s@@"), name.c_str()));
- break;
-
- case PlayerRelation::DISREGARDED:
- mBrowserBox->addRow(strprintf(_("@@unignore|Un-Ignore %s@@"), name.c_str()));
- mBrowserBox->addRow(strprintf(_("@@ignore|Completely ignore %s@@"), name.c_str()));
- break;
-
- case PlayerRelation::IGNORED:
- mBrowserBox->addRow(strprintf(_("@@unignore|Un-Ignore %s@@"), name.c_str()));
- break;
+ case PlayerRelation::NEUTRAL:
+ mBrowserBox->addRow(strprintf(_("@@friend|Befriend %s@@"), name.c_str()));
+
+ case PlayerRelation::FRIEND:
+ mBrowserBox->addRow(strprintf(_("@@disregard|Disregard %s@@"), name.c_str()));
+ mBrowserBox->addRow(strprintf(_("@@ignore|Ignore %s@@"), name.c_str()));
+ break;
+
+ case PlayerRelation::DISREGARDED:
+ mBrowserBox->addRow(strprintf(_("@@unignore|Un-Ignore %s@@"), name.c_str()));
+ mBrowserBox->addRow(strprintf(_("@@ignore|Completely ignore %s@@"), name.c_str()));
+ break;
+
+ case PlayerRelation::IGNORED:
+ mBrowserBox->addRow(strprintf(_("@@unignore|Un-Ignore %s@@"), name.c_str()));
+ break;
}
//mBrowserBox->addRow(_("@@follow|Follow ") + name + "@@");
@@ -143,58 +144,60 @@ void PopupMenu::showPopup(int x, int y, FloorItem *floorItem)
void PopupMenu::handleLink(const std::string& link)
{
+ Being *being = beingManager->findBeing(mBeingId);
+
// Talk To action
if (link == "talk" &&
- mBeing != NULL &&
- mBeing->getType() == Being::NPC &&
+ being != NULL &&
+ being->getType() == Being::NPC &&
current_npc == 0)
{
- dynamic_cast<NPC*>(mBeing)->talk();
+ dynamic_cast<NPC*>(being)->talk();
}
// Trade action
else if (link == "trade" &&
- mBeing != NULL &&
- mBeing->getType() == Being::PLAYER)
+ being != NULL &&
+ being->getType() == Being::PLAYER)
{
- player_node->trade(mBeing);
- tradePartnerName = mBeing->getName();
+ player_node->trade(being);
+ tradePartnerName = being->getName();
}
// Attack action
else if (link == "attack" &&
- mBeing != NULL &&
- mBeing->getType() == Being::PLAYER)
+ being != NULL &&
+ being->getType() == Being::PLAYER)
{
- player_node->attack(mBeing, true);
+ player_node->attack(being, true);
}
else if (link == "unignore" &&
- mBeing != NULL &&
- mBeing->getType() == Being::PLAYER)
+ being != NULL &&
+ being->getType() == Being::PLAYER)
{
- player_relations.setRelation(mBeing->getName(), PlayerRelation::NEUTRAL);
+ player_relations.setRelation(being->getName(), PlayerRelation::NEUTRAL);
}
else if (link == "ignore" &&
- mBeing != NULL &&
- mBeing->getType() == Being::PLAYER)
+ being != NULL &&
+ being->getType() == Being::PLAYER)
{
- player_relations.setRelation(mBeing->getName(), PlayerRelation::IGNORED);
+ player_relations.setRelation(being->getName(), PlayerRelation::IGNORED);
}
else if (link == "disregard" &&
- mBeing != NULL &&
- mBeing->getType() == Being::PLAYER)
+ being != NULL &&
+ being->getType() == Being::PLAYER)
{
- player_relations.setRelation(mBeing->getName(), PlayerRelation::DISREGARDED);
+ player_relations.setRelation(being->getName(), PlayerRelation::DISREGARDED);
}
else if (link == "friend" &&
- mBeing != NULL &&
- mBeing->getType() == Being::PLAYER)
+ being != NULL &&
+ being->getType() == Being::PLAYER)
{
- player_relations.setRelation(mBeing->getName(), PlayerRelation::FRIEND);
+ player_relations.setRelation(being->getName(), PlayerRelation::FRIEND);
}
/*
@@ -205,12 +208,12 @@ void PopupMenu::handleLink(const std::string& link)
/*
// Add Buddy action
- else if ((link == "buddy") && mBeing != NULL && mBeing->isPlayer())
+ else if ((link == "buddy") && being != NULL && being->isPlayer())
{
if (!buddyWindow->isVisible())
buddyWindow->setVisible(true);
- buddyWindow->addBuddy(mBeing->getName());
+ buddyWindow->addBuddy(being->getName());
}*/
// Pick Up Floor Item action
@@ -254,12 +257,12 @@ void PopupMenu::handleLink(const std::string& link)
new ItemAmountWindow(AMOUNT_ITEM_DROP, inventoryWindow, mItem);
}
else if (link == "party-invite" &&
- mBeing != NULL &&
- mBeing->getType() == Being::PLAYER)
+ being != NULL &&
+ being->getType() == Being::PLAYER)
{
MessageOut outMsg(player_node->getNetwork());
outMsg.writeInt16(CMSG_PARTY_INVITE);
- outMsg.writeInt32(mBeing->getId());
+ outMsg.writeInt32(being->getId());
}
// Unknown actions
@@ -270,7 +273,7 @@ void PopupMenu::handleLink(const std::string& link)
setVisible(false);
- mBeing = NULL;
+ mBeingId = 0;
mFloorItem = NULL;
mItem = NULL;
}
diff --git a/src/gui/popupmenu.h b/src/gui/popupmenu.h
index 715a9bb5..2694abd8 100644
--- a/src/gui/popupmenu.h
+++ b/src/gui/popupmenu.h
@@ -22,6 +22,8 @@
#ifndef POPUP_MENU_H
#define POPUP_MENU_H
+#include <SDL.h> // for Uint32
+
#include "linkhandler.h"
#include "window.h"
@@ -66,7 +68,7 @@ class PopupMenu : public Window, public LinkHandler
private:
BrowserBox* mBrowserBox;
- Being* mBeing;
+ Uint32 mBeingId;
FloorItem* mFloorItem;
Item *mItem;
diff --git a/src/gui/recorder.cpp b/src/gui/recorder.cpp
index c7989495..153bffae 100644
--- a/src/gui/recorder.cpp
+++ b/src/gui/recorder.cpp
@@ -2,7 +2,7 @@
* A chat recorder
* Copyright (C) 2008 Lloyd Bryant <lloyd_bryant@netzero.net>
*
- * This file is part of Aethyra.
+ * This file is part of The Mana World.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
diff --git a/src/gui/recorder.h b/src/gui/recorder.h
index 4f41ff42..0bbab012 100644
--- a/src/gui/recorder.h
+++ b/src/gui/recorder.h
@@ -2,7 +2,7 @@
* A chat recorder
* Copyright (C) 2008 Lloyd Bryant <lloyd_bryant@netzero.net>
*
- * This file is part of Aethyra.
+ * This file is part of The Mana World.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
diff --git a/src/gui/setup.cpp b/src/gui/setup.cpp
index 19575cfb..09eaeff0 100644
--- a/src/gui/setup.cpp
+++ b/src/gui/setup.cpp
@@ -22,7 +22,7 @@
#include "button.h"
#include "setup.h"
#include "setup_audio.h"
-#include "setup_colours.h"
+#include "setup_colors.h"
#include "setup_joystick.h"
#include "setup_keyboard.h"
#include "setup_players.h"
@@ -90,7 +90,7 @@ Setup::Setup():
panel->addTab(_("Keyboard"), tab);
mTabs.push_back(tab);
- tab = new Setup_Colours();
+ tab = new Setup_Colors();
panel->addTab(_("Colors"), tab);
mTabs.push_back(tab);
diff --git a/src/gui/setup_colours.cpp b/src/gui/setup_colors.cpp
index 49e08aeb..269f8fd1 100644
--- a/src/gui/setup_colours.cpp
+++ b/src/gui/setup_colors.cpp
@@ -20,17 +20,18 @@
*/
#include <string>
+#include <cmath>
#include <guichan/listmodel.hpp>
#include <guichan/widgets/label.hpp>
#include <guichan/widgets/slider.hpp>
#include "browserbox.h"
-#include "colour.h"
+#include "color.h"
#include "itemlinkhandler.h"
#include "listbox.h"
#include "scrollarea.h"
-#include "setup_colours.h"
+#include "setup_colors.h"
#include "slider.h"
#include "textfield.h"
@@ -41,16 +42,16 @@
#include "../utils/gettext.h"
#include "../utils/tostring.h"
-Setup_Colours::Setup_Colours() :
+Setup_Colors::Setup_Colors() :
mSelected(-1)
{
setOpaque(false);
- mColourBox = new ListBox(textColour);
- mColourBox->setActionEventId("colour_box");
- mColourBox->addActionListener(this);
+ mcolorBox = new ListBox(textColor);
+ mcolorBox->setActionEventId("color_box");
+ mcolorBox->addActionListener(this);
- mScroll = new ScrollArea(mColourBox);
+ mScroll = new ScrollArea(mcolorBox);
mScroll->setHorizontalScrollPolicy(gcn::ScrollArea::SHOW_NEVER);
mPreview = new BrowserBox(BrowserBox::AUTO_WRAP);
@@ -128,7 +129,7 @@ Setup_Colours::Setup_Colours() :
setDimension(gcn::Rectangle(0, 0, 290, 250));
}
-Setup_Colours::~Setup_Colours()
+Setup_Colors::~Setup_Colors()
{
delete mRedLabel;
delete mRedSlider;
@@ -145,20 +146,20 @@ Setup_Colours::~Setup_Colours()
delete mScroll;
}
-void Setup_Colours::action(const gcn::ActionEvent &event)
+void Setup_Colors::action(const gcn::ActionEvent &event)
{
- if (event.getId() == "colour_box")
+ if (event.getId() == "color_box")
{
- mSelected = mColourBox->getSelected();
- int col = textColour->getColourAt(mSelected);
- char ch = textColour->getColourCharAt(mSelected);
+ mSelected = mcolorBox->getSelected();
+ int col = textColor->getColorAt(mSelected);
+ char ch = textColor->getColorCharAt(mSelected);
std::string msg;
if (ch == '<')
- msg = toString("@@|") +
+ msg = toString("@@|") +
_("This is what the color looks like") + "@@";
else
- msg = "##" + toString(ch) +
+ msg = "##" + toString(ch) +
_("This is what the color looks like");
mPreview->clearRows();
@@ -171,33 +172,27 @@ void Setup_Colours::action(const gcn::ActionEvent &event)
if (event.getId() == "slider_red")
{
- char buffer[30];
- std::sprintf(buffer, "%d", static_cast<int>(mRedSlider->getValue()));
- mRedText->setText(buffer);
- updateColour();
+ mRedText->setText(toString(std::floor(mRedSlider->getValue())));
+ updateColor();
return;
}
if (event.getId() == "slider_green")
{
- char buffer[30];
- std::sprintf(buffer, "%d", static_cast<int>(mGreenSlider->getValue()));
- mGreenText->setText(buffer);
- updateColour();
+ mGreenText->setText(toString(std::floor(mGreenSlider->getValue())));
+ updateColor();
return;
}
if (event.getId() == "slider_blue")
{
- char buffer[30];
- std::sprintf(buffer, "%d", static_cast<int>(mBlueSlider->getValue()));
- mBlueText->setText(buffer);
- updateColour();
+ mBlueText->setText(toString(std::floor(mBlueSlider->getValue())));
+ updateColor();
return;
}
}
-void Setup_Colours::setEntry(gcn::Slider *s, TextField *t, int value)
+void Setup_Colors::setEntry(gcn::Slider *s, TextField *t, int value)
{
s->setValue(value);
char buffer[100];
@@ -205,43 +200,43 @@ void Setup_Colours::setEntry(gcn::Slider *s, TextField *t, int value)
t->setText(buffer);
}
-void Setup_Colours::apply()
+void Setup_Colors::apply()
{
- textColour->commit();
+ textColor->commit();
}
-void Setup_Colours::cancel()
+void Setup_Colors::cancel()
{
- textColour->rollback();
- int col = textColour->getColourAt(mSelected);
+ textColor->rollback();
+ int col = textColor->getColorAt(mSelected);
setEntry(mRedSlider, mRedText, col >> 16);
setEntry(mGreenSlider, mGreenText, (col >> 8) & 0xff);
setEntry(mBlueSlider, mBlueText, col & 0xff);
}
-void Setup_Colours::listen(const TextField *tf)
+void Setup_Colors::listen(const TextField *tf)
{
if (tf == mRedText)
{
mRedSlider->setValue(tf->getValue());
- updateColour();
+ updateColor();
return;
}
if (tf == mGreenText)
{
mGreenSlider->setValue(tf->getValue());
- updateColour();
+ updateColor();
return;
}
if (tf == mBlueText)
{
mBlueSlider->setValue(tf->getValue());
- updateColour();
+ updateColor();
return;
}
}
-void Setup_Colours::updateColour()
+void Setup_Colors::updateColor()
{
if (mSelected == -1)
{
@@ -250,5 +245,5 @@ void Setup_Colours::updateColour()
int rgb = static_cast<int>(mRedSlider->getValue()) << 16 |
static_cast<int>(mGreenSlider->getValue()) << 8 |
static_cast<int>(mBlueSlider->getValue());
- textColour->setColourAt(mSelected, rgb);
+ textColor->setColorAt(mSelected, rgb);
}
diff --git a/src/gui/setup_colours.h b/src/gui/setup_colors.h
index 57d9e304..1e56cfa8 100644
--- a/src/gui/setup_colours.h
+++ b/src/gui/setup_colors.h
@@ -36,19 +36,19 @@
class BrowserBox;
-class Setup_Colours : public SetupTab, public gcn::ActionListener,
+class Setup_Colors : public SetupTab, public gcn::ActionListener,
public TextFieldListener
{
public:
- Setup_Colours();
- ~Setup_Colours();
+ Setup_Colors();
+ ~Setup_Colors();
void apply();
void cancel();
void action(const gcn::ActionEvent &event);
void listen(const TextField *tf);
private:
- gcn::ListBox *mColourBox;
+ gcn::ListBox *mcolorBox;
gcn::ScrollArea *mScroll;
BrowserBox *mPreview;
gcn::ScrollArea *mPreviewBox;
@@ -70,6 +70,6 @@ class Setup_Colours : public SetupTab, public gcn::ActionListener,
int mBlueValue;
void setEntry(gcn::Slider *s, TextField *t, int value);
- void updateColour();
+ void updateColor();
};
#endif
diff --git a/src/gui/setup_keyboard.cpp b/src/gui/setup_keyboard.cpp
index 06a5a520..5d7519ef 100644
--- a/src/gui/setup_keyboard.cpp
+++ b/src/gui/setup_keyboard.cpp
@@ -1,6 +1,7 @@
/*
- * The Mana World
- * Copyright (C) 2007 The Mana World Development Team
+ * Custom keyboard shortcuts configuration
+ * Copyright (C) 2007 Joshua Langley <joshlangley@optusnet.com.au>
+ * Copyright (C) 2009 The Mana World Development Team
*
* This file is part of The Mana World.
*
diff --git a/src/gui/setup_keyboard.h b/src/gui/setup_keyboard.h
index 082fa84d..dee12135 100644
--- a/src/gui/setup_keyboard.h
+++ b/src/gui/setup_keyboard.h
@@ -1,6 +1,6 @@
/*
- * The Mana World
- * Copyright (C) 2007 The Mana World Development Team
+ * Custom keyboard shortcuts configuration
+ * Copyright (C) 2007 Joshua Langley <joshlangley@optusnet.com.au>
*
* This file is part of The Mana World.
*
diff --git a/src/gui/setup_players.cpp b/src/gui/setup_players.cpp
index 7e76055a..5c19bd2b 100644
--- a/src/gui/setup_players.cpp
+++ b/src/gui/setup_players.cpp
@@ -67,9 +67,9 @@ static const char *RELATION_NAMES[PlayerRelation::RELATIONS_NR] = {
class PlayerRelationListModel : public gcn::ListModel
{
public:
- virtual ~PlayerRelationListModel(void) { }
+ virtual ~PlayerRelationListModel() { }
- virtual int getNumberOfElements(void)
+ virtual int getNumberOfElements()
{
return PlayerRelation::RELATIONS_NR;
}
@@ -85,30 +85,30 @@ public:
class PlayerTableModel : public TableModel
{
public:
- PlayerTableModel(void) :
+ PlayerTableModel() :
mPlayers(NULL)
{
playerRelationsUpdated();
}
- virtual ~PlayerTableModel(void)
+ virtual ~PlayerTableModel()
{
freeWidgets();
if (mPlayers)
delete mPlayers;
}
- virtual int getRows(void)
+ virtual int getRows()
{
return mPlayers->size();
}
- virtual int getColumns(void)
+ virtual int getColumns()
{
return COLUMNS_NR;
}
- virtual int getRowHeight(void)
+ virtual int getRowHeight()
{
return ROW_HEIGHT;
}
@@ -121,7 +121,7 @@ public:
return RELATION_CHOICE_COLUMN_WIDTH;
}
- virtual void playerRelationsUpdated(void)
+ virtual void playerRelationsUpdated()
{
signalBeforeUpdate();
@@ -164,7 +164,7 @@ public:
return mWidgets[WIDGET_AT(row, column)];
}
- virtual void freeWidgets(void)
+ virtual void freeWidgets()
{
if (mPlayers)
delete mPlayers;
@@ -193,9 +193,9 @@ protected:
class IgnoreChoicesListModel : public gcn::ListModel
{
public:
- virtual ~IgnoreChoicesListModel(void) { }
+ virtual ~IgnoreChoicesListModel() { }
- virtual int getNumberOfElements(void)
+ virtual int getNumberOfElements()
{
return player_relations.getPlayerIgnoreStrategies()->size();
}
@@ -292,7 +292,7 @@ Setup_Players::Setup_Players():
setDimension(gcn::Rectangle(0, 0, 290, 250));
}
-Setup_Players::~Setup_Players(void)
+Setup_Players::~Setup_Players()
{
player_relations.removeListener(this);
}
diff --git a/src/gui/setup_video.cpp b/src/gui/setup_video.cpp
index 1775665f..b1d33b09 100644
--- a/src/gui/setup_video.cpp
+++ b/src/gui/setup_video.cpp
@@ -289,7 +289,7 @@ void Setup_Video::apply()
* See http://libsdl.org/cgi/docwiki.cgi/SDL_SetVideoMode
*/
-#ifdef WIN32
+#if defined(WIN32) || defined(__APPLE__)
// checks for opengl usage
if (!(config.getValue("opengl", false) == 1))
{
@@ -307,7 +307,7 @@ void Setup_Video::apply()
logger->error(error.str());
}
}
-#ifdef WIN32
+#if defined(WIN32) || defined(__APPLE__)
} else {
new OkDialog(_("Switching to full screen"),
_("Restart needed for changes to take effect."));
diff --git a/src/gui/shoplistbox.cpp b/src/gui/shoplistbox.cpp
index b5761535..94187818 100644
--- a/src/gui/shoplistbox.cpp
+++ b/src/gui/shoplistbox.cpp
@@ -22,7 +22,7 @@
#include <guichan/font.hpp>
#include <guichan/listmodel.hpp>
-#include "colour.h"
+#include "color.h"
#include "shop.h"
#include "shoplistbox.h"
@@ -64,9 +64,9 @@ void ShopListBox::draw(gcn::Graphics *gcnGraphics)
mAlpha = config.getValue("guialpha", 0.8);
bool valid;
- const int red = (textColour->getColour('H', valid) >> 16) & 0xFF;
- const int green = (textColour->getColour('H', valid) >> 8) & 0xFF;
- const int blue = textColour->getColour('H', valid) & 0xFF;
+ const int red = (textColor->getColor('H', valid) >> 16) & 0xFF;
+ const int green = (textColor->getColor('H', valid) >> 8) & 0xFF;
+ const int blue = textColor->getColor('H', valid) & 0xFF;
const int alpha = mAlpha * 255;
Graphics *graphics = static_cast<Graphics*>(gcnGraphics);
diff --git a/src/gui/skill.cpp b/src/gui/skill.cpp
index dd7c3a4e..5cf8c51f 100644
--- a/src/gui/skill.cpp
+++ b/src/gui/skill.cpp
@@ -45,9 +45,14 @@ struct SkillInfo {
bool modifiable;
};
+static const SkillInfo fakeSkillInfo = {
+ _("Mystery Skill"),
+ false
+};
+
std::vector<SkillInfo> skill_db;
-static void initSkillinfo(void);
+static void initSkillinfo();
class SkillGuiTableModel : public StaticTableModel
{
@@ -73,15 +78,13 @@ public:
return 35;
}
- virtual int getRowHeight(void)
+ virtual int getRowHeight()
{
return 12;
}
- virtual void update(void)
+ virtual void update()
{
- static const SkillInfo fakeSkillInfo = { _("???"), false };
-
mEntriesNr = mDialog->getSkills().size();
resize();
@@ -112,7 +115,6 @@ public:
}
}
-
private:
SkillDialog *mDialog;
int mEntriesNr;
@@ -172,10 +174,18 @@ void SkillDialog::action(const gcn::ActionEvent &event)
if (selectedSkill >= 0)
player_node->raiseSkill(mSkillList[selectedSkill]->id);
}
- else if (event.getId() == "skill")
+ else if (event.getId() == "skill" && mTable->getSelectedRow() > -1)
{
- mIncButton->setEnabled(mTable->getSelectedRow() > -1 &&
- player_node->mSkillPoint > 0);
+ SKILL *skill = mSkillList[mTable->getSelectedRow()];
+ SkillInfo const *info;
+
+ if (skill->id >= 0 && (unsigned int) skill->id < skill_db.size())
+ info = &skill_db[skill->id];
+ else
+ info = &fakeSkillInfo;
+
+ mIncButton->setEnabled(player_node->mSkillPoint > 0 &&
+ info->modifiable);
}
else if (event.getId() == "close")
setVisible(false);
@@ -246,11 +256,11 @@ void SkillDialog::setSkill(int id, int lvl, int mp)
void SkillDialog::cleanList()
{
- for_each(mSkillList.begin(), mSkillList.end(), make_dtor(mSkillList));
+ delete_all(mSkillList);
mSkillList.clear();
}
-static void initSkillinfo(void)
+static void initSkillinfo()
{
SkillInfo emptySkillInfo = { "", false };
diff --git a/src/gui/skill.h b/src/gui/skill.h
index 91c2b640..0600d106 100644
--- a/src/gui/skill.h
+++ b/src/gui/skill.h
@@ -65,7 +65,7 @@ class SkillDialog : public Window, public gcn::ActionListener
void setSkill(int id, int lv, int sp);
void cleanList();
- const std::vector<SKILL*>& getSkills(void) const { return mSkillList; }
+ const std::vector<SKILL*>& getSkills() const { return mSkillList; }
private:
GuiTable *mTable;
diff --git a/src/gui/speechbubble.cpp b/src/gui/speechbubble.cpp
index f8c69e87..c76558e4 100644
--- a/src/gui/speechbubble.cpp
+++ b/src/gui/speechbubble.cpp
@@ -1,22 +1,21 @@
/*
- * The Legend of Mazzeroth
- * Copyright (C) 2008, The Legend of Mazzeroth Development Team
+ * Speech bubbles
+ * Copyright (C) 2008 The Legend of Mazzeroth Development Team
*
- * This file is part of The Legend of Mazzeroth based on original code
- * from The Mana World.
+ * This file is part of The Mana World.
*
- * The Legend of Mazzeroth is free software; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* any later version.
*
- * The Legend of Mazzeroth is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with The Legend of Mazzeroth; if not, write to the Free Software
+ * along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
diff --git a/src/gui/speechbubble.h b/src/gui/speechbubble.h
index 43267a4e..d2d81332 100644
--- a/src/gui/speechbubble.h
+++ b/src/gui/speechbubble.h
@@ -1,22 +1,21 @@
/*
- * The Legend of Mazzeroth
- * Copyright (C) 2008, The Legend of Mazzeroth Development Team
+ * Speech bubbles
+ * Copyright (C) 2008 The Legend of Mazzeroth Development Team
*
- * This file is part of The Legend of Mazzeroth based on original code
- * from The Mana World.
+ * This file is part of The Mana World.
*
- * The Legend of Mazzeroth is free software; you can redistribute it and/or modify
+ * This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* any later version.
*
- * The Legend of Mazzeroth is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with The Legend of Mazzeroth; if not, write to the Free Software
+ * along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
diff --git a/src/gui/status.cpp b/src/gui/status.cpp
index 271b6f1e..e8426ec4 100644
--- a/src/gui/status.cpp
+++ b/src/gui/status.cpp
@@ -78,8 +78,11 @@ StatusWindow::StatusWindow(LocalPlayer *player):
mStatsDefenseLabel= new gcn::Label(_("Defense:"));
mStatsMagicAttackLabel = new gcn::Label(_("M.Attack:"));
mStatsMagicDefenseLabel = new gcn::Label(_("M.Defense:"));
+ // Gettext flag for next line: xgettext:no-c-format
mStatsAccuracyLabel = new gcn::Label(_("% Accuracy:"));
+ // Gettext flag for next line: xgettext:no-c-format
mStatsEvadeLabel = new gcn::Label(_("% Evade:"));
+ // Gettext flag for next line: xgettext:no-c-format
mStatsReflexLabel = new gcn::Label(_("% Reflex:"));
mStatsAttackPoints = new gcn::Label;
@@ -307,3 +310,4 @@ void StatusWindow::action(const gcn::ActionEvent &event)
}
}
}
+
diff --git a/src/gui/table.cpp b/src/gui/table.cpp
index 674f3891..1ee9da0f 100644
--- a/src/gui/table.cpp
+++ b/src/gui/table.cpp
@@ -23,7 +23,7 @@
#include <guichan/graphics.hpp>
#include <guichan/key.hpp>
-#include "colour.h"
+#include "color.h"
#include "table.h"
#include "../configuration.h"
@@ -37,7 +37,7 @@ class GuiTableActionListener : public gcn::ActionListener
public:
GuiTableActionListener(GuiTable *_table, gcn::Widget *_widget, int _row, int _column);
- virtual ~GuiTableActionListener(void);
+ virtual ~GuiTableActionListener();
virtual void action(const gcn::ActionEvent& actionEvent);
@@ -62,7 +62,7 @@ GuiTableActionListener::GuiTableActionListener(GuiTable *table, gcn::Widget *wid
}
}
-GuiTableActionListener::~GuiTableActionListener(void)
+GuiTableActionListener::~GuiTableActionListener()
{
if (mWidget)
{
@@ -96,12 +96,12 @@ GuiTable::GuiTable(TableModel *initial_model, gcn::Color background,
addKeyListener(this);
}
-GuiTable::~GuiTable(void)
+GuiTable::~GuiTable()
{
delete mModel;
}
-TableModel* GuiTable::getModel(void) const
+TableModel *GuiTable::getModel() const
{
return mModel;
}
@@ -124,7 +124,7 @@ void GuiTable::setModel(TableModel *new_model)
}
}
-void GuiTable::recomputeDimensions(void)
+void GuiTable::recomputeDimensions()
{
int rows_nr = mModel->getRows();
int columns_nr = mModel->getColumns();
@@ -152,12 +152,12 @@ void GuiTable::setSelected(int row, int column)
mSelectedRow = row;
}
-int GuiTable::getSelectedRow(void)
+int GuiTable::getSelectedRow()
{
return mSelectedRow;
}
-int GuiTable::getSelectedColumn(void)
+int GuiTable::getSelectedColumn()
{
return mSelectedColumn;
}
@@ -167,7 +167,7 @@ void GuiTable::setLinewiseSelection(bool linewise)
mLinewiseMode = linewise;
}
-int GuiTable::getRowHeight(void)
+int GuiTable::getRowHeight()
{
if (mModel)
return mModel->getRowHeight() + 1; // border
@@ -199,7 +199,7 @@ void GuiTable::setSelectedRow(int selected)
{
mSelectedRow = 0;
}
- else if ((selected >= mModel->getRows() && !mWrappingEnabled) ||
+ else if ((selected >= mModel->getRows() && !mWrappingEnabled) ||
(selected < 0 && mWrappingEnabled))
{
mSelectedRow = mModel->getRows() - 1;
@@ -224,7 +224,7 @@ void GuiTable::setSelectedColumn(int selected)
{
mSelectedColumn = 0;
}
- else if ((selected >= mModel->getColumns() && !mWrappingEnabled) ||
+ else if ((selected >= mModel->getColumns() && !mWrappingEnabled) ||
(selected < 0 && mWrappingEnabled))
{
mSelectedColumn = mModel->getColumns() - 1;
@@ -242,7 +242,7 @@ void GuiTable::uninstallActionListeners(void)
action_listeners.clear();
}
-void GuiTable::installActionListeners(void)
+void GuiTable::installActionListeners()
{
if (!mModel)
return;
@@ -291,7 +291,7 @@ void GuiTable::draw(gcn::Graphics* graphics)
int max_rows_nr = mModel->getRows() - first_row; // clip if neccessary:
if (max_rows_nr < rows_nr)
rows_nr = max_rows_nr;
-
+
// Now determine the first and last column
// Take the easy way out; these are usually bounded and all visible.
int first_column = 0;
@@ -324,11 +324,11 @@ void GuiTable::draw(gcn::Graphics* graphics)
if (!mLinewiseMode && c == mSelectedColumn && r == mSelectedRow)
{
bool valid;
- const int red =
- (textColour->getColour('H', valid) >> 16) & 0xFF;
+ const int red =
+ (textColor->getColor('H', valid) >> 16) & 0xFF;
const int green =
- (textColour->getColour('H', valid) >> 8) & 0xFF;
- const int blue = textColour->getColour('H', valid) & 0xFF;
+ (textColor->getColor('H', valid) >> 8) & 0xFF;
+ const int blue = textColor->getColor('H', valid) & 0xFF;
const int alpha = mAlpha * 127;
graphics->setColor(gcn::Color(red, green, blue, alpha));
@@ -346,11 +346,11 @@ void GuiTable::draw(gcn::Graphics* graphics)
if (mLinewiseMode && r == mSelectedRow)
{
bool valid;
- const int red =
- (textColour->getColour('H', valid) >> 16) & 0xFF;
+ const int red =
+ (textColor->getColor('H', valid) >> 16) & 0xFF;
const int green =
- (textColour->getColour('H', valid) >> 8) & 0xFF;
- const int blue = textColour->getColour('H', valid) & 0xFF;
+ (textColor->getColor('H', valid) >> 8) & 0xFF;
+ const int blue = textColor->getColor('H', valid) & 0xFF;
const int alpha = mAlpha * 127;
graphics->setColor(gcn::Color(red, green, blue, alpha));
@@ -383,7 +383,7 @@ void GuiTable::moveToBottom(gcn::Widget *widget)
mTopWidget = NULL;
}
-gcn::Rectangle GuiTable::getChildrenArea(void)
+gcn::Rectangle GuiTable::getChildrenArea()
{
return gcn::Rectangle(0, 0, getWidth(), getHeight());
}
@@ -401,25 +401,25 @@ void GuiTable::keyPressed(gcn::KeyEvent& keyEvent)
else if (key.getValue() == gcn::Key::UP)
{
setSelectedRow(mSelectedRow - 1);
-
+
keyEvent.consume();
}
else if (key.getValue() == gcn::Key::DOWN)
{
setSelectedRow(mSelectedRow + 1);
-
+
keyEvent.consume();
}
else if (key.getValue() == gcn::Key::LEFT)
{
setSelectedColumn(mSelectedColumn - 1);
-
+
keyEvent.consume();
}
else if (key.getValue() == gcn::Key::RIGHT)
{
setSelectedColumn(mSelectedColumn + 1);
-
+
keyEvent.consume();
}
else if (key.getValue() == gcn::Key::HOME)
@@ -477,7 +477,7 @@ void GuiTable::mouseWheelMovedDown(gcn::MouseEvent& mouseEvent)
mouseEvent.consume();
}
}
-
+
void GuiTable::mouseDragged(gcn::MouseEvent& mouseEvent)
{
}
@@ -497,7 +497,7 @@ void GuiTable::modelUpdated(bool completed)
}
}
-gcn::Widget* GuiTable::getWidgetAt(int x, int y)
+gcn::Widget *GuiTable::getWidgetAt(int x, int y)
{
int row = getRowForY(y);
int column = getColumnForX(x);
@@ -549,12 +549,13 @@ void GuiTable::_setFocusHandler(gcn::FocusHandler* focusHandler)
{
gcn::Widget::_setFocusHandler(focusHandler);
- if (mModel)
- for (int r = 0; r < mModel->getRows(); ++r)
- for (int c = 0; c < mModel->getColumns(); ++c)
- {
+ if (mModel) {
+ for (int r = 0; r < mModel->getRows(); ++r) {
+ for (int c = 0; c < mModel->getColumns(); ++c) {
gcn::Widget *w = mModel->getElementAt(r, c);
if (w)
w->_setFocusHandler(focusHandler);
}
+ }
+ }
}
diff --git a/src/gui/table.h b/src/gui/table.h
index 912eb284..841f6ef2 100644
--- a/src/gui/table.h
+++ b/src/gui/table.h
@@ -46,17 +46,19 @@ class GuiTable : public gcn::Widget,
public gcn::KeyListener,
public TableModelListener
{
- friend class GuiTableActionListener; // so that the action listener can call distributeActionEvent
+ // so that the action listener can call distributeActionEvent
+ friend class GuiTableActionListener;
+
public:
GuiTable(TableModel * initial_model = NULL, gcn::Color background = 0xffffff,
bool opacity = true);
- virtual ~GuiTable(void);
+ virtual ~GuiTable();
/**
* Retrieves the active table model
*/
- TableModel *getModel(void) const;
+ TableModel *getModel() const;
/**
* Sets the table model
@@ -72,9 +74,9 @@ public:
void setSelected(int row, int column);
- int getSelectedRow(void);
+ int getSelectedRow();
- int getSelectedColumn(void);
+ int getSelectedColumn();
void setSelectedRow(int selected);
@@ -136,25 +138,25 @@ public:
virtual void mouseWheelMovedUp(gcn::MouseEvent& mouseEvent);
virtual void mouseWheelMovedDown(gcn::MouseEvent& mouseEvent);
-
+
virtual void mouseDragged(gcn::MouseEvent& mouseEvent);
// Constraints inherited from TableModelListener
virtual void modelUpdated(bool);
protected:
+ /** Frees all action listeners on inner widgets. */
+ virtual void uninstallActionListeners();
+ /** Installs all action listeners on inner widgets. */
+ virtual void installActionListeners();
- virtual void uninstallActionListeners(void); // frees all action listeners on inner widgets
- virtual void installActionListeners(void); // installs all action listeners on inner widgets
-
- virtual int getRowHeight(void);
+ virtual int getRowHeight();
virtual int getColumnWidth(int i);
-
-private:
+private:
int getRowForY(int y); // -1 on error
int getColumnForX(int x); // -1 on error
- void recomputeDimensions(void);
+ void recomputeDimensions();
bool mLinewiseMode;
bool mWrappingEnabled;
bool mOpaque;
@@ -171,11 +173,14 @@ private:
int mSelectedRow;
int mSelectedColumn;
- int mPopFramesNr; // Number of frames to skip upwards when drawing the selected widget
+ /** Number of frames to skip upwards when drawing the selected widget. */
+ int mPopFramesNr;
- gcn::Widget *mTopWidget; // If someone moves a fresh widget to the top, we must display it
+ /** If someone moves a fresh widget to the top, we must display it. */
+ gcn::Widget *mTopWidget;
- std::vector<GuiTableActionListener *> action_listeners; // Vector for compactness; used as a list in practice.
+ /** Vector for compactness; used as a list in practice. */
+ std::vector<GuiTableActionListener *> action_listeners;
};
diff --git a/src/gui/table_model.cpp b/src/gui/table_model.cpp
index 19e780f3..4fa13bae 100644
--- a/src/gui/table_model.cpp
+++ b/src/gui/table_model.cpp
@@ -35,13 +35,13 @@ void TableModel::removeListener(TableModelListener *listener)
listeners.erase(listener);
}
-void TableModel::signalBeforeUpdate(void)
+void TableModel::signalBeforeUpdate()
{
for (std::set<TableModelListener *>::const_iterator it = listeners.begin(); it != listeners.end(); it++)
(*it)->modelUpdated(false);
}
-void TableModel::signalAfterUpdate(void)
+void TableModel::signalAfterUpdate()
{
for (std::set<TableModelListener *>::const_iterator it = listeners.begin(); it != listeners.end(); it++)
(*it)->modelUpdated(true);
@@ -60,12 +60,12 @@ StaticTableModel::StaticTableModel(int row, int column) :
mWidths.resize(column, 1);
}
-StaticTableModel::~StaticTableModel(void)
+StaticTableModel::~StaticTableModel()
{
delete_all(mTableModel);
}
-void StaticTableModel::resize(void)
+void StaticTableModel::resize()
{
mRows = getRows();
mColumns = getColumns();
@@ -97,7 +97,7 @@ void StaticTableModel::set(int row, int column, gcn::Widget *widget)
signalAfterUpdate();
}
-gcn::Widget* StaticTableModel::getElementAt(int row, int column)
+gcn::Widget *StaticTableModel::getElementAt(int row, int column)
{
return mTableModel[WIDGET_AT(row, column)];
}
@@ -119,7 +119,7 @@ void StaticTableModel::fixRowHeight(int height)
mHeight = -height;
}
-int StaticTableModel::getRowHeight(void)
+int StaticTableModel::getRowHeight()
{
return abs(mHeight);
}
@@ -132,12 +132,12 @@ int StaticTableModel::getColumnWidth(int column)
return abs(mWidths[column]);
}
-int StaticTableModel::getRows(void)
+int StaticTableModel::getRows()
{
return mRows;
}
-int StaticTableModel::getColumns(void)
+int StaticTableModel::getColumns()
{
return mColumns;
}
diff --git a/src/gui/table_model.h b/src/gui/table_model.h
index 1d966e8b..9ca36120 100644
--- a/src/gui/table_model.h
+++ b/src/gui/table_model.h
@@ -29,8 +29,9 @@ class TableModelListener
{
public:
/**
- * Must be invoked by the TableModel whenever a global change is about to occur or
- * has occurred (e.g., when a row or column is being removed or added).
+ * Must be invoked by the TableModel whenever a global change is about to
+ * occur or has occurred (e.g., when a row or column is being removed or
+ * added).
*
* This method is triggered twice, once before and once after the update.
*
@@ -45,22 +46,22 @@ public:
class TableModel
{
public:
- virtual ~TableModel(void) { }
+ virtual ~TableModel() { }
/**
* Determines the number of rows (lines) in the table
*/
- virtual int getRows(void) = 0;
+ virtual int getRows() = 0;
/**
* Determines the number of columns in each row
*/
- virtual int getColumns(void) = 0;
+ virtual int getColumns() = 0;
/**
* Determines the height for each row
*/
- virtual int getRowHeight(void) = 0;
+ virtual int getRowHeight() = 0;
/**
* Determines the width of each individual column
@@ -80,12 +81,12 @@ protected:
/**
* Tells all listeners that the table is about to see an update
*/
- virtual void signalBeforeUpdate(void);
+ virtual void signalBeforeUpdate();
/**
* Tells all listeners that the table has seen an update
*/
- virtual void signalAfterUpdate(void);
+ virtual void signalAfterUpdate();
private:
std::set<TableModelListener *> listeners;
@@ -96,7 +97,7 @@ class StaticTableModel : public TableModel
{
public:
StaticTableModel(int width, int height);
- virtual ~StaticTableModel(void);
+ virtual ~StaticTableModel();
/**
* Inserts a widget into the table model.
@@ -106,7 +107,8 @@ public:
virtual void set(int row, int column, gcn::Widget *widget);
/**
- * Fixes the column width for a given column; this overrides dynamic width inference.
+ * Fixes the column width for a given column; this overrides dynamic width
+ * inference.
*
* Semantics are undefined for width 0.
*/
@@ -122,17 +124,16 @@ public:
/**
* Resizes the table model
*/
- virtual void resize(void);
+ virtual void resize();
- virtual int getRows(void);
- virtual int getColumns(void);
- virtual int getRowHeight(void);
- virtual int getWidth(void);
- virtual int getHeight(void);
+ virtual int getRows();
+ virtual int getColumns();
+ virtual int getRowHeight();
+ virtual int getWidth();
+ virtual int getHeight();
virtual int getColumnWidth(int index);
virtual gcn::Widget *getElementAt(int row, int column);
-
protected:
int mRows, mColumns;
int mHeight;
diff --git a/src/gui/truetypefont.cpp b/src/gui/truetypefont.cpp
index 6e8efeff..66855b77 100644
--- a/src/gui/truetypefont.cpp
+++ b/src/gui/truetypefont.cpp
@@ -45,8 +45,7 @@ class TextChunk
bool operator==(const TextChunk &chunk) const
{
- return (
- chunk.text == text && chunk.color == color);
+ return (chunk.text == text && chunk.color == color);
}
void generate(TTF_Font *font)
@@ -81,7 +80,7 @@ typedef std::list<TextChunk>::iterator CacheIterator;
static int fontCounter;
-TrueTypeFont::TrueTypeFont(const std::string& filename, int size)
+TrueTypeFont::TrueTypeFont(const std::string &filename, int size)
{
if (fontCounter == 0 && TTF_Init() == -1)
{
@@ -162,7 +161,7 @@ void TrueTypeFont::drawString(gcn::Graphics *graphics,
g->drawImage(cache.front().img, x, y);
}
-int TrueTypeFont::getWidth(const std::string& text) const
+int TrueTypeFont::getWidth(const std::string &text) const
{
int w, h;
TTF_SizeUTF8(mFont, text.c_str(), &w, &h);
diff --git a/src/gui/truetypefont.h b/src/gui/truetypefont.h
index bd338d84..cd68a94e 100644
--- a/src/gui/truetypefont.h
+++ b/src/gui/truetypefont.h
@@ -45,7 +45,7 @@ class TrueTypeFont : public gcn::Font
* @param filename Font filename.
* @param size Font size.
*/
- TrueTypeFont(const std::string& filename, int size);
+ TrueTypeFont(const std::string &filename, int size);
/**
* Destructor.
@@ -59,7 +59,9 @@ class TrueTypeFont : public gcn::Font
/**
* @see Font::drawString
*/
- void drawString(gcn::Graphics* graphics, const std::string& text, int x, int y);
+ void drawString(gcn::Graphics *graphics,
+ const std::string &text,
+ int x, int y);
private:
TTF_Font *mFont;
diff --git a/src/gui/viewport.cpp b/src/gui/viewport.cpp
index 6b6c982a..f5a6edb4 100644
--- a/src/gui/viewport.cpp
+++ b/src/gui/viewport.cpp
@@ -19,6 +19,7 @@
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/
+#include "ministatus.h"
#include "popupmenu.h"
#include "viewport.h"
@@ -74,6 +75,8 @@ void Viewport::setMap(Map *map)
mMap = map;
}
+extern MiniStatusWindow *miniStatusWindow;
+
void Viewport::draw(gcn::Graphics *gcnGraphics)
{
static int lastTick = tick_time;
@@ -211,6 +214,9 @@ void Viewport::draw(gcn::Graphics *gcnGraphics)
(*i)->drawEmotion(graphics, -(int) mPixelViewX, -(int) mPixelViewY);
}
+ if (miniStatusWindow)
+ miniStatusWindow->drawIcons(graphics);
+
// Draw contained widgets
WindowContainer::draw(gcnGraphics);
}
diff --git a/src/gui/widgets/dropdown.cpp b/src/gui/widgets/dropdown.cpp
index 31d35cb0..29c6c69c 100644
--- a/src/gui/widgets/dropdown.cpp
+++ b/src/gui/widgets/dropdown.cpp
@@ -23,7 +23,7 @@
#include "dropdown.h"
-#include "../colour.h"
+#include "../color.h"
#include "../listbox.h"
#include "../scrollarea.h"
@@ -40,7 +40,7 @@ Image *DropDown::buttons[2][2];
ImageRect DropDown::skin;
float DropDown::mAlpha = config.getValue("guialpha", 0.8);
-DropDown::DropDown(gcn::ListModel *listModel, gcn::ScrollArea *scrollArea,
+DropDown::DropDown(gcn::ListModel *listModel, gcn::ScrollArea *scrollArea,
gcn::ListBox *listBox, bool opacity):
gcn::DropDown::DropDown(listModel, scrollArea, listBox),
mOpaque(opacity)
@@ -138,7 +138,7 @@ void DropDown::draw(gcn::Graphics* graphics)
const int alpha = mAlpha * 255;
gcn::Color faceColor = getBaseColor();
faceColor.a = alpha;
- gcn::Color highlightColor = textColour->getColour('H', valid);
+ gcn::Color highlightColor = textColor->getColor('H', valid);
highlightColor.a = alpha;
gcn::Color shadowColor = faceColor - 0x303030;
shadowColor.a = alpha;
diff --git a/src/gui/window.cpp b/src/gui/window.cpp
index 8000179d..797b4be9 100644
--- a/src/gui/window.cpp
+++ b/src/gui/window.cpp
@@ -728,4 +728,3 @@ void Window::reflowLayout(int w, int h)
mLayout = NULL;
setContentSize(w, h);
}
-
diff --git a/src/gui/window.h b/src/gui/window.h
index 25bf903a..518de6e9 100644
--- a/src/gui/window.h
+++ b/src/gui/window.h
@@ -30,7 +30,6 @@
#include "../guichanfwd.h"
class ConfigListener;
-class GCContainer;
class ContainerPlacer;
class Image;
class ImageRect;
@@ -177,7 +176,7 @@ class Window : public gcn::Window, gcn::WidgetListener
*
* @return The parent window or <code>NULL</code> if there is none.
*/
- Window* getParentWindow() { return mParent; }
+ Window *getParentWindow() { return mParent; }
/**
* Schedule this window for deletion. It will be deleted at the start
@@ -222,7 +221,7 @@ class Window : public gcn::Window, gcn::WidgetListener
/**
* Returns the name of the window. This is not the window title.
*/
- const std::string& getWindowName() { return mWindowName; }
+ const std::string &getWindowName() { return mWindowName; }
/**
* Reads the position (and the size for resizable windows) in the
@@ -300,7 +299,6 @@ class Window : public gcn::Window, gcn::WidgetListener
void setGuiAlpha();
- GCContainer *mChrome; /**< Contained container */
ResizeGrip *mGrip; /**< Resize grip */
Window *mParent; /**< The parent window */
Layout *mLayout; /**< Layout handler */
diff --git a/src/gui/colour.h b/src/gui/color.h
index 6ea02840..509448e7 100644
--- a/src/gui/colour.h
+++ b/src/gui/color.h
@@ -27,110 +27,110 @@
#include <guichan/listmodel.hpp>
-class Colour : public gcn::ListModel
+class Color : public gcn::ListModel
{
public:
/**
* Constructor
*/
- Colour();
+ Color();
/**
* Destructor
*/
- ~Colour();
+ ~Color();
/**
* Define the colour replacement for a character
*
* @param c charater to be replaced
* @param rgb colour to replace character
*/
- void setColour(const char c, const int rgb);
+ void setColor(const char c, const int rgb);
/**
* Define the colour replacement for a character
*
* @param c character to be replaced
* @param r red component
* @param g green component
* @param b blue component
*/
- void setColour(const char c, const int r, const int g, const int b)
+ void setColor(const char c, const int r, const int g, const int b)
{
- setColour(c, (r << 16) | (g << 8) | b);
+ setColor(c, (r << 16) | (g << 8) | b);
}
/**
* Return the colour associated with a character, if exists
*
* @param c character requested
* @param valid indicate whether character is known
*/
- int getColour(const char c, bool &valid) const;
+ int getColor(const char c, bool &valid) const;
/**
- * Return the number of colours known
+ * Return the number of colors known
*/
int getNumberOfElements() {return mColVector.size(); }
/**
* Return the name of the ith colour
*
* @param i index of colour interested in
*/
std::string getElementAt(int i);
/**
* Get the colour for the element at index i in the current colour
* model
*/
- int getColourAt(int i);
+ int getColorAt(int i);
/**
* Get the character used by the colour for the element at index i in
* the current colour model
*/
- char getColourCharAt(int i);
+ char getColorCharAt(int i);
/**
* Set the colour for the element at index i
*/
- void setColourAt(int i, int rgb);
+ void setColorAt(int i, int rgb);
/**
- * Commit the colours
+ * Commit the colors
*/
void commit();
/**
- * Rollback the colours
+ * Rollback the colors
*/
void rollback();
private:
- struct ColourElem
+ struct colorElem
{
- ColourElem(const char c, const int rgb, const std::string &text) :
+ colorElem(const char c, const int rgb, const std::string &text) :
ch(c), rgb(rgb), text(text) {}
char ch;
int rgb;
int committedRgb;
std::string text;
};
- typedef std::vector<ColourElem> ColVector;
+ typedef std::vector<colorElem> ColVector;
ColVector mColVector;
/**
- * Initialise colour
+ * Initialise color
*
* @param c character that needs initialising
* @param rgb default colour if not found in config
* @param text identifier of colour
*/
- void addColour(const char c, const int rgb, const std::string &text);
+ void addColor(const char c, const int rgb, const std::string &text);
};
-extern Colour *textColour;
+extern Color *textColor;
#endif
@@ -27,110 +27,110 @@
/**
- * Define the colour replacement for a character
+ * Define the color replacement for a character
*
* @param c charater to be replaced
@@ -27,110 +27,110 @@
*
* @param c charater to be replaced
- * @param rgb colour to replace character
+ * @param rgb color to replace character
*/
@@ -27,110 +27,110 @@
/**
- * Define the colour replacement for a character
+ * Define the color replacement for a character
*
* @param c character to be replaced
@@ -27,110 +27,110 @@
}
/**
- * Return the colour associated with a character, if exists
+ * Return the color associated with a character, if exists
*
* @param c character requested
@@ -27,110 +27,110 @@
int getNumberOfElements() {return mColVector.size(); }
/**
- * Return the name of the ith colour
+ * Return the name of the ith color
*
@@ -27,110 +27,110 @@
*
- * @param i index of colour interested in
+ * @param i index of color interested in
*/
std::string getElementAt(int i);
@@ -27,110 +27,110 @@
std::string getElementAt(int i);
/**
- * Get the colour for the element at index i in the current colour
+ * Get the color for the element at index i in the current color
* model
*/
@@ -27,110 +27,110 @@
/**
- * Get the character used by the colour for the element at index i in
- * the current colour model
+ * Get the character used by the color for the element at index i in
+ * the current color model
*/
@@ -27,110 +27,110 @@
/**
- * Set the colour for the element at index i
+ * Set the color for the element at index i
*/
@@ -27,110 +27,110 @@
*
* @param c character that needs initialising
- * @param rgb default colour if not found in config
- * @param text identifier of colour
+ * @param rgb default color if not found in config
+ * @param text identifier of color
*/